function [ P, Q, dt ] = test_1( n , metoda, rysuj)
%test_1 - ilustracja, z jaka dokladnoscia s obliczane wspolczynniki wielomianu
%         interpolujacego Lagrange'a
%  1. Budujemy przykladowy wielomian stopnia n - P(n).
%  2. Wybrane punkty tego wielomianu traktujemy jako wezly zadane w zadaniu interplacji 
%  3. Jeeli liczba wybranych wezlow jest rowna n+1, to rozwiazaniem
%  zadania interpolcji powinien by wielomian Q(n) tosamy z naszym, pierwotnie
%  zbudowanym P(n).
%  4. Porownanie wspolczynnikow obu wielomianow ilustruje dokladnosc metody
%  znajdowania wspolczynnikow wielomianu interpolujcego.

% Parametry funkcji:  
% wejciowe: n - stopie wielomianu, n+1 wezlow,
%            metoda = 0 - Lagrange'a,
%                     1 - z macierza Vandermonde'a,
%                     2 - Newtona,
%                     3 - z biblioteki Curve Fitting Toolbox
%            rysuj - nr wykresu (0 - nie rysuj wykresow wielomianow),
% wyjsciowe: P,Q - wektory wspolczynnikow wielomianow P i Q,
%            dt - czas obliczania wspolczynnikow.

% Budowanie wielomianu testowego.
a = -floor(n/2);  b = a+2*n-2; % [a,b] przedzial, w ktorym sa zera wielomianu
z = a:2:b;               % zera wielomianu s rozlozone rownomiernie  
P = poly(z);             % obliczenie wspolczynnikow wielomianu
% Wybor wezlow.
xi = (a-1):2:(b+1);   % wezly rozlozone rownomiernie  
yi = polyval(P,xi);   % rzedne wezlow
% Iterpolacja Lagrange'a
switch metoda
    case 0                    % z wzoru Lagrange'a
        [Q,dt]=lagrange(xi,yi);
        [Q,dt]=lagrange(xi,yi);
    case 1                    % z macierza Vandermonde'a
        [Q,dt]=lagrvand(xi,yi);
        [Q,dt]=lagrvand(xi,yi);
    case 2                    % metoda Newtona
        [Q,dt]=lagrnewt(xi,yi);
        [Q,dt]=lagrnewt(xi,yi);
    case 3                    % z biblioteki MATLABa
        Q = polyfit(xi,yi,n);
        tic;
        Q = polyfit(xi,yi,n);
        dt = toc;
    otherwise
        disp('Blad numer metody'); Q = NaN, dt = 0; pause, rysuj = 0;
end

if(rysuj),
    xx = (a-1):0.01:(b+1);  yyP = polyval(P,xx); yyQ = polyval(Q,xx);
    figure(rysuj);
    plot(xx,yyP,'b',xi,yi,'ko',xx,yyQ,'r'), 
    legend('oryginalny','wezly','interpolujacy','Location','Best');
end

end

